@@ -1,27 +1,14 @@
 /*  This file is part of the KDE libraries
 
-    Copyright (c) 2004 Zack Rusin <zack@kde.org>
-    Copyright (c) 2006 Jacob R Rideout <kde@jacobrideout.net>
-    Copyright (c) 2009 Jakub Stachowski <qbast@go2.pl>
+    SPDX-FileCopyrightText: 2004 Zack Rusin <zack@kde.org>
+    SPDX-FileCopyrightText: 2006 Jacob R Rideout <kde@jacobrideout.net>
+    SPDX-FileCopyrightText: 2009 Jakub Stachowski <qbast@go2.pl>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <QtCore/QList>
-#include <QtCore/QString>
+#include <QList>
+#include <QString>
 
 #include "tokenizer_p.h"
 #include "textbreaks_p.h"
@@ -188,11 +175,11 @@ QStringRef WordTokenizer::next()
 
     // check if this word starts an email address of url
     if (!d->inAddress || hasNext()) {
-        int pos = n.position()+n.length();
-        if (d->buffer[pos] == QLatin1Char('@')) {
+        const int pos = n.position()+n.length();
+        if ((pos < d->buffer.length()) && d->buffer[pos] == QLatin1Char('@')) {
             d->inAddress = true;
         }
-        if (d->buffer[pos] == QLatin1Char(':') && d->buffer[pos+1] == QLatin1Char('/')
+        if ((pos + 2 < d->buffer.length()) && d->buffer[pos] == QLatin1Char(':') && d->buffer[pos+1] == QLatin1Char('/')
             && d->buffer[pos+2] == QLatin1Char('/')) {
             d->inAddress = true;
         }
